#
# spec file for package jfbterm
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           jfbterm
Version:        0.4.7
Release:        14.4
Summary:        Framebuffer Terminal to Display Japanese Characters
License:        BSD-3-Clause
Group:          System/Console
# Summary(ja): Linux の framebuffer 上で漢字を表示するためのプログラムです。
Url:            http://jfbterm.sourceforge.jp/
Source0:        http://iij.dl.sourceforge.jp/jfbterm/13501/%{name}-%{version}.tar.gz
Source1:        terminfo.jfbterm
Source2:        termcap.jfbterm
Patch0:         jfbterm-0.4.7-conf.patch
Patch2:         jfbterm-0.4.7-remove-sticky.patch
Patch3:         jfbterm-0.4.7-infinite_loop.patch
Patch4:         jfbterm-0.4.7-userspace.patch
Patch5:         jfbterm-0.4.7-remove-warning.patch
Patch6:         jfbterm-0.4.7-mmap-newkernel.patch
Patch7:         jfbterm-0.4.7-hang-onexit.patch
Patch8:         jfbterm-0.4.7-pagemask_userspace.patch
# Some people see jfbterm hang or segv with invalid ut_id
# (bug 698532)
Patch9:         jfbterm-0.4.7-hang-on-utmp-refresh-with-invalid-utid.patch
# Fix encoding for AUTHORS
Patch10:        jfbterm-0.4.7-AUTHORS-encoding.patch
BuildRequires:  automake
BuildRequires:  ncurses-devel
%if 0%{?suse_version} > 1130
BuildRequires:  utempter-devel
%else
BuildRequires:  utempter
%endif
Requires(post): %{_bindir}/grep
Requires(post): /bin/cat
Requires(post): permissions
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#
# SuSE series: j

%description
JFBTERM is a program to display Japanese Kanji characters using the
framebuffer. Similar to the well-known program kon, it uses a terminal
emulator on the console and hooks into its output. But JFBTERM does not
use VGA (like kon does). It uses the framebuffer instead.

%description -l ja
JFBTERM は Linux の framebuffer 上で漢字を表示するためのプログラムです。
KON 同様に疑似端末を使ってコンソール出力をフックしますが、VGA ではなく、
framebuffer に展開しています。

%prep
%setup -q
%patch0 -p1 -b .conf
%patch2 -p1 -b .remove_sticky
%patch3 -p1 -b .userspace
%patch4 -p1 -b .infinite_loop
%patch5 -p1 -b .remove_warn
%patch6 -p1 -b .nmap_newkernel
%patch7 -p1 -b .hang_onexit
%patch8 -p1 -b .pagemask
%patch9 -p1 -b .utid_with_refresh
%patch10 -p1
cp %{SOURCE1} .
cp %{SOURCE2} .

%build
#aclocal
#automake -a --gnu --include-deps
#autoconf
touch Makefile.in aclocal.m4 config.h.in configure stamp-h.in
# fix non-position-independent-executable error
export LDFLAGS="-pie"
export CFLAGS="%{optflags} -fPIE -fomit-frame-pointer -fgnu89-inline"
# ----------------------------------
%configure
make %{?_smp_mflags}

%install
# "make install" doesn't work well here, therefore I do it manually
# there are only two files anyway.
# make prefix=$RPM_BUILD_ROOT/ install
# mv $RPM_BUILD_ROOT/etc/jfbterm.conf.sample $RPM_BUILD_ROOT/etc/jfbterm.conf
mkdir -p %{buildroot}%{_sysconfdir}
mkdir -p %{buildroot}%{_bindir}
install -m 4755 jfbterm %{buildroot}%{_bindir}/jfbterm
install -m 644 jfbterm.conf.sample %{buildroot}%{_sysconfdir}/jfbterm.conf
mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_mandir}/man5
install -m 644 jfbterm.1 %{buildroot}%{_mandir}/man1
install -m 644 jfbterm.conf.5 %{buildroot}%{_mandir}/man5
# install terminfo entry-description
# mkdir -p $RPM_BUILD_ROOT/usr/share/terminfo/j
# TERMINFO=$RPM_BUILD_ROOT/usr/share/terminfo tic terminfo.jfbterm

%post
%if 0%{?sles_version}
%run_permissions
%else
%set_permissions %{_bindir}/jfbterm
%endif
# canuum needs a termcap entry, without it canuum won't run under jfbterm:
if [ -f etc/termcap ]; then
    if [ `grep -c '^jfbterm|japanese framebuffer terminal' etc/termcap` -eq 0 ]; then
	cat %{_defaultdocdir}/jfbterm/termcap.jfbterm >> etc/termcap
    fi
fi

%verifyscript
%verify_permissions -e %{_bindir}/jfbterm

%files
%defattr(-, root, root)
%doc NEWS AUTHORS COPYING README ChangeLog
%doc terminfo.jfbterm termcap.jfbterm
%config %{_sysconfdir}/jfbterm.conf
%{_mandir}/man1/jfbterm.1*
%{_mandir}/man5/jfbterm.conf.5*
%verify(not mode) %attr(0755,root,tty) %{_bindir}/jfbterm

%changelog
* Mon Jun 15 2015 schwab@suse.de
- Run specfile through spec-cleaner
- Build with %%{optflags}
- Force gnu89 inline semantics
- jfbterm-0.4.7-AUTHORS-encoding.patch: remove backup file
* Thu Jan 10 2013 belphegor@belbel.or.jp
- corrected font paths
* Sun Mar 25 2012 hillwood@linuxfans.org
- fix Source URLs
* Sun Mar 25 2012 hillwood@linuxfans.org
- add a man page
- fix AUTHORS encoding to UTF-8
* Sun Mar 25 2012 swyear@yahoo.com.tw
- Fix build for X86_64
* Fri Mar 23 2012 hillwood@linuxfans.org
- Update to 0.4.7
  * Fix local exploit
- Fix build for openSUSE 12.2
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Sep  9 2010 aj@suse.de
- BuildRequire utempter-devel
* Sat Apr 26 2008 coolo@suse.de
- fix build
* Wed Sep 26 2007 mfabian@suse.de
- Bugzilla #309094: fonts are now in /usr/share/fonts.
* Wed Sep 26 2007 mfabian@suse.de
- Bugzilla #309093: don't package terminfo entry, it is already
  in the terminfo package.
* Thu Mar 29 2007 rguenther@suse.de
- add ncurses-devel BuildRequires
* Fri May 19 2006 ro@suse.de
- fix build on ppc64
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 22 2005 ro@suse.de
- fix implicit declaration
* Thu Oct 30 2003 ro@suse.de
- package according to permissions.secure and add %%run_permissions
- no root for build
* Tue Sep 16 2003 mfabian@suse.de
- Bugzilla #31101: fix attributes of /usr/bin/jfbterm to agree
  with /etc/permissions*. Now set to
    "%%attr(6755,root,tty) /usr/bin/jfbterm"
* Thu Aug  1 2002 mfabian@suse.de
- add /bin/cat /usr/bin/grep to Prereq:
* Thu Feb  7 2002 mfabian@suse.de
- canuum really needs the /etc/termcap entry, therefore I added
  add a "%%post" script again which adds termcap entry if
  the file etc/termcap exists and doesn't yet have an entry for
  jfbterm
* Sat Feb  2 2002 ro@suse.de
- call automake first to fix build
* Thu Jan 31 2002 okir@suse.de
- various security fixes/changes:
  * open framebuffer and /dev/console as the very first
    thing in main(), then drop privs
  * use utempter to add/remove utmp entry
  * close all open fds > 2 before executing the shell.
  NB: jfbterm would pass the framebuffer fd to the user's
  shell.
* Mon May  7 2001 mfabian@suse.de
- bzip2 sources
* Tue Apr 10 2001 mfabian@suse.de
- remove "%%post" script to add /etc/termcap entry. It is not
  needed and causes problems when the file /etc/termcap is not
  yet installed.
* Sat Apr  7 2001 mfabian@suse.de
- forgot to remove "Prereq: /usr/bin/tic"
* Fri Mar 30 2001 uli@suse.de
- disabled direct VGA access for non-x86 archs
* Tue Mar 27 2001 mfabian@suse.de
- don't call "tic" in %%post, pack terminfo entry-description
  into the rpm instead
* Wed Feb 14 2001 mfabian@suse.de
- fix compile problem due to "missing linux/config.h"
* Wed Sep 20 2000 mfabian@suse.de
- new package jfbterm, version 0.3.10
- Included fix for buffer overflow in tapp_init(main.c) pointed out
  by Fumitoshi UKAI <ukai@debian.org>
- The original version refers to terminfo entry 'kon', but the SuSE
  rpm version refers to the terminfo entry 'jfbterm', which is
  actually the same as 'kon' apart from the different name.
  The terminfo.jfbterm file has been copied from terminfo.kon and
  only the name has been changed.
- fixed font paths and font file names in config file.
